@@ -5,7 +5,7 @@ use v5.020;
 use Moo;
 use Types::Standard qw( Maybe Str );
 
-$Number::MuPhone::VERSION = '1.0';
+$Number::MuPhone::VERSION = '1.01';
 
 our $MUPHONE_BASE_DIR = $ENV{MUPHONE_BASE_DIR} || $ENV{HOME}.'/.muphone';
 our $EXTENSION_REGEX  = qr/(?:\*|extension|ext|x)/;
@@ -28,7 +28,7 @@ Number::MuPhone::Data->import('$MUPHONE_DATA');
 
 =head1 NAME
 
-Number::MuPhone - parsing and using phone numbers in pure Perl
+Number::MuPhone - parsing and displaying phone numbers in pure Perl
 
 NOTE: this is a full rewrite and is not backwards compatible with earlier
 versions of this module.
@@ -38,14 +38,14 @@ versions of this module.
 Parse, validate (loosely in some cases) and display phone numbers as expected.
 
 This has stripped down functionality compared to libphonenumber, but it is
-also Pure Perl (TM), is a bit simpler to use, and contains the core functionality
+also Pure Perl (TM), is simpler to use, and contains the core functionality
 needed by common use cases.
 
-If you have functionality requests, please let me know: <clive.holloway@gmail.com>
+If you have functionality requests, please let me know: L<mailto:clive.holloway@gmail.com>
 
 All number regexes are derived from the XML file supplied by:
 
-    https://github.com/google/libphonenumber/
+L<https://github.com/google/libphonenumber/>
 
 
 =head2 BASIC USAGE
@@ -79,54 +79,6 @@ Instantiate an instance using one of the following syntaxes
       # process the error
     }
 
-=head2 KEEPING UP TO DATE WITH CHANGES...
-
-The data used to validate and format the phone numbers comes fropm Google's libphonenumber:
-
-TODO: add URL
-
-This distribution comes with a reasonably recent copy of the libphonenumber source XML, but
-you can also set up a cron to update your source data weekly, to ensure you don't have
-problems with new area codes as they get added (this happens probably more often than you think).
-
-By default, MuPhone's update script (perl-muphone-build-data)  will create a ~/.muphon
- directory and dump everything in there if you choose to update periodically (or when
-starting a Docker container, say)
-
-If you want to store the data elsewhere, set the MUPHONE_BASE_DIR env var to specify
-where you want it stored. Wherever you store it, the directory must be writeable by
-the user.
-
-Currently, the extractor script only grabs the data we need, and removes spacing, to keep the size down.
-
-If you want to examine all available data, set $DEBUG=1 (add in padding) and set
-$STRIP_SUPERFLUOUS_DATA=0 in the script and run it again.
-
-for the following, paths are relative to the  ~/.muphone or $ENV{MUPHONE_BASE_DIR} dirs as appropriate
-
-./etc/PhoneNumberMetadata.xml - the libphonenumber source XML file
-./lib/NumberMuPhoneData.pm    - the generated Number::MuPhone::Data 
-./t/check_data_module.t       - a little sanity script that runs after creating the data file
-
-=head3 Initial run
-
-Optionally, set the MUPHONE_BASE_DIR environment variable to point to your config directory (must be writeable).
-Otherwise, ~/.muphone will get used (default).
-
-As the user, run:
-
-perl-muphone-build-data
-
-Confirm the tests pass and the files are created (if not error output, tests passed).
-
-=head3 Set up the cron to run weekly to update the data
-
-# using default data dir
-0 5 * * 1 /usr/local/bin/perl-muphone-build-data
-
-# using user specific data dir
-0 5 * * 1 MUPHONE_BASE_DIR=/path/to/config /usr/local/bin/perl-muphone-build-data
-
 
 =head1 PUBLIC ATTRIBUTES
 
@@ -137,7 +89,7 @@ around BUILDARGS => sub {
 
   # args are probably a hashref - { number => $number, country => 'US' }
   # but can use a shortcut, if preferred
-  # ($number, 'US') 
+  # ($number, 'US')
 
   if (ref $args[0] ne 'HASH' and @args>2) {
     die "Bad args - must be a hashref of name args or (\$num,\$country_code)";
@@ -149,7 +101,7 @@ around BUILDARGS => sub {
     $args[0]->{country} = pop @args
       if $args[1];
   }
- 
+
   return $class->$orig(@args);
 };
 
@@ -158,7 +110,7 @@ sub BUILD {
 
   # extract number and extension, determine countrycode from number,
   # strip off possible national/international dial prefix
-  # and store attributes as needed 
+  # and store attributes as needed
   $self->_process_raw_number;
 
 }
@@ -173,7 +125,7 @@ has number => (
   isa      => Str,
   is       => 'ro',
   required => 1,
-); 
+);
 
 =head2 extension
 
@@ -197,11 +149,11 @@ has country => (
   isa  => Maybe[Str],
   is   => 'rw',
   lazy => 1,
-); 
+);
 
 =head2 error
 
-If the args don't point to a valid number at instantiation, this error will be set
+If the args don't lead to a valid number at instantiation, this error will be set
 
 =cut
 
@@ -209,11 +161,11 @@ has error => (
   isa      => Str,
   is       => 'rw',
   default  => '',
-); 
+);
 
 =head2 country_name
 
-Full text name of country()
+Full text name of country (may be inaccurate for single arg instantiation - see below)
 
 =cut
 
@@ -278,7 +230,7 @@ has national_display => (
   }
 );
 
-=head2 national_display
+=head2 international_display
 
 Display this number in the international number format (E.123)
 
@@ -419,7 +371,7 @@ sub _get_country_from {
 
 =head1 METHODS
 
-=head2 dial_from 
+=head2 dial_from
 
 How to dial the number from the number/country sent in as an arg. eg
 
@@ -453,7 +405,7 @@ sub dial_from {
   }
 }
 
-=head2 display_from 
+=head2 display_from
 
 How to display the number for the number/country sent in as an arg. eg
 
@@ -562,11 +514,13 @@ sub _process_raw_number {
     my $format = $format_hash->{format};
 
     my $regex_statement = "\$num =~ s/$pattern/$format/;";
+    ## no critic
     eval $regex_statement;
-      if ($@) {
+    ## use  critic
+    if ($@) {
       $self->error("Can't format number($num) with regex($regex_statement): $@");
       last FORMAT;
-      }
+    }
 
     $national_prefix_optional = $format_hash->{nationalPrefixOptionalWhenFormatting}
                                 ? 1 : 0;
@@ -611,14 +565,92 @@ sub _process_from_e123 {
                                         : '';
     $national_number_format_regex
       or next COUNTRY;
-    
+
     $num =~ $national_number_format_regex
       or next COUNTRY;
-    
+
     $self->country($country);
     $self->_cleaned_number($num);
   }
 
 }
 
+=head2 A WARNING ABOUT INFERRED COUNTRIES
+
+If you instantiate an object with an E.123 formatted number, the inferred country will be
+the 'main' country for that number. This is because Number::MuPhone is currently using the
+loosest regex available to validate a number for a country (this may change soon). This
+affects these area codes:
+
+    Code       Main Country
+    ====       ============
+    1          US
+    44         GB
+    212        EH
+    61         CC
+    590        MF
+    7          KZ
+    599        BQ
+    47         SJ
+    262        YT
+
+As far as functionality is concerned, you should see no difference, unless you want to use
+the country() attribute. To avoid this, instantiate with both number and country.
+
+=head2 KEEPING UP TO DATE WITH CHANGES IN THE SOURCE XML FILE
+
+The data used to validate and format the phone numbers comes from Google's libphonenumber:
+
+L<https://github.com/google/libphonenumber/releases/latest>
+
+This distribution should come with a reasonably recent copy of the libphonenumber source XML,
+but you can also set up a cron to update your source data weekly, to ensure you don't have
+problems with new area codes as they get added (this happens probably more often than you think).
+
+By default, Number::MuPhone's update script (perl-muphone-build-data) stores this data in the
+~/.muphone directory, but you can overload this by setting the MUPHONE_BASE_DIR environment
+variable. Wherever you choose, it must be writeable by the user, and remember to expose the same
+ENV var to any scripts using Number::MuPhone (if needed).
+
+When run, the following files are created in the  ~/.muphone or $ENV{MUPHONE_BASE_DIR} dirs as appropriate
+
+    ./etc/PhoneNumberMetadata.xml     # the libphonenumber source XML file
+    ./lib/NumberMuPhoneData.pm        # the generated Number::MuPhone::Data
+    ./t/check_data_module.t           # a little sanity script that runs after creating the data file
+
+Currently, the extractor script only grabs the data we need, and removes spacing, to keep the size down.
+
+If you want to examine all available data, set C<$DEBUG=1> (add in padding, switch commas to =>) and set
+C<$STRIP_SUPERFLUOUS_DATA=0> in the script and run it again. then look at the generated NumberMuPhoneData.pm
+
+=head3 Initial run
+
+Optionally, set the MUPHONE_BASE_DIR environment variable to point to your config directory (must be writeable).
+Otherwise, ~/.muphone will get used (default).
+
+As the appropriate user, run:
+
+    perl-muphone-build-data
+
+Confirm the tests pass and the files are created (if no error output, tests passed, and all should be good).
+
+=head3 Set up the cron to run weekly to update the data
+
+# using default data dir (~/.muphone)
+0 5 * * 1 /usr/local/bin/perl-muphone-build-data
+
+# using user specific data dir
+0 5 * * 1 MUPHONE_BASE_DIR=/path/to/config /usr/local/bin/perl-muphone-build-data
+
+=head3 Dockerfile config
+
+Similarly, add the perl-muphone-build-data script to your Dockerfile, as appropriate. If you're using
+Kubernetes, this might be enough, but for longer running Docker instances, you might want to
+consider setting up the cronjob within the image too.
+
+If anyone has best practice recommendations for this, let me know and I'll update the POD :D
+
+=cut
+
+
 1;
